==> IT14408-1.3.0.1.tar.gz: usr/lib/python2.7/site-packages/powervc_ttv/config/data_mgr.py <==
# =================================================================
# Licensed Materials - Property of IBM
#
# (c) Copyright IBM Corp. 2015 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# =================================================================

from powervc_oslo.config import data_mgr as mgr
from powervc_oslo.config import data_utils as utils
from powervc_oslo.config.data_utils import V122, V123, V130

TTV_CONF = '/etc/ttv-validation/ttv-validation.conf'
TTV_PASTE = '/etc/ttv-validation/api-paste.ini'


######################################################
#           TTV Data Manager Definition              #
######################################################
class TTVDataManager(mgr.BaseDataManager):

    def get_component_name(self):
        """Provides the name of the Component providing the Data Manager"""
        return 'validator'

    def is_supported_environment(self):
        """Specifies whether the Component is supported in this Environment"""
        return utils.is_management_system()

    def get_dependent_managers(self):
        """Specifies the Component Name of the Managers it is dependent on"""
        return ['httpd']

    ###############################################
    #     Data Manager - Configure Interface      #
    ###############################################
    def configure_component(self):
        """Performs Configuration specific to the given Component"""
        super(TTVDataManager, self).configure_component()
        # Replace the Router Factory in the Paste Configuration file
        sedbefore = 'ttv_validation.api.v1.router:APIRouter.factory'
        sedafter = 'powervc_ttv.api.v1.router:PowerVCAPIRouter.factory'
        utils.sed_replace(TTV_PASTE, sedbefore, sedafter)

    ###############################################
    #   Data Manager - Subclass Implementation    #
    ###############################################
    def _added_policy_file(self, config, cat):
        self._added_old_policy_file(config, cat)

    def _deleted_policy_properties(self, config):
        """Helper method to delete policy file path"""
        pass

    def _get_service_user(self):
        """Provides the name of the Service User for the Component"""
        return 'ttv-validation'

    def _get_enabled_services(self):
        """Provides a list of the Services for the Component"""
        return ['ttv-validation-api']

    def _get_service_log_files(self):
        """Provides a list of Service Log Files for the Component"""
        logs = ['api', 'httpd-error', 'ttv_manager', 'valFlowMgr',
                'powervc-validate']
        return ['/var/log/ttv-validation/%s.log' % log for log in logs]

    def _get_added_conf_properties(self):
        """Provides a dictionary of configuration properties to add"""
        config = {TTV_CONF: dict(), TTV_PASTE: dict()}
        # Add any of the KeystoneAuth and Messaging added properties
        self._added_auth_conf_properties(config[TTV_CONF])
        # Add in the TTV specific properties to the Configuration Files
        self.__added_ttv_conf_properties(config[TTV_CONF])
        # Add messaging support for auditing
        self._added_messaging_conf_properties(config[TTV_CONF])
        self._added_ras_conf_properties(config[TTV_CONF])
        self.__added_ttv_paste_properties(config[TTV_PASTE])
        # Until Legacy is removed, we need to set update the user name
        config[TTV_CONF]['keystone_authtoken']['password'] =\
            ('aes:%(ttv-validation_password)s', V123)
        return config

    def _get_deleted_conf_properties(self):
        """Provides a dictionary of configuration properties to remove"""
        config = {TTV_CONF: dict(), TTV_PASTE: dict()}
        # Remove any of the KeystoneAuth and Messaging deleted properties
        self._deleted_auth_conf_properties(config[TTV_CONF])
        self._deleted_messaging_conf_properties(config[TTV_CONF])
        self.__deleted_ttv_paste_properties(config[TTV_PASTE])
        config[TTV_PASTE]['filter:authtoken']['auth_version'] = V123
        config[TTV_CONF]['DEFAULT'].update(
            sql_connection=V123, rpc_backend=V123)
        return config

    def _get_audit_conf_properties(self, version=None):
        """Provides a tuple of configuration properties for auditing"""
        return (TTV_PASTE, ['composite:ttv_validation_api_v1'], ['keystone'])

    def _get_included_backup_files(self):
        """Provides a list of Component files to include in a backup"""
        return ['/etc/ttv-validation']

    def _get_service_password_properties(self):
        """Provides a list of the configuration properties for passwords"""
        return [('ttv-validation', TTV_CONF,
                 'keystone_authtoken', 'password')]

    ###############################################
    #    Internal Data Manager Helper Methods     #
    ###############################################
    def __added_ttv_conf_properties(self, config):
        """Add in the TTV validator.conf Configuration Properties"""
        # Add in the properties for the DEFAULT Section
        config['DEFAULT'].update(dict(
            OCFS_TTV=('False', V123),
            host_interface=('%(ip_interface)s', V123),
            ttv_validation_api_listen_port=('8428', V123),
            ttv_validation_api_listen=('%(local_ip)s', V123),
            api_paste_config=('/etc/ttv-validation/api-paste.ini', V123),
            formatter=('powervc_ttv.api.extension.powervcFormatter', V123),
            policy_file=('/opt/ibm/powervc/policy/'
                         'ttv-validation/policy.json', V123),
            solution_spec=('/opt/ibm/powervc/ttv-validation/'
                           'conf/solution_spec.json', V123),
            resources_def=('/opt/ibm/powervc/ttv-validation/'
                           'conf/resources.json', V123),
            category_map=('/opt/ibm/powervc/ttv-validation/conf/'
                          'category_validator_map.json', V123),
            category_validator_map=('/opt/ibm/powervc/ttv-validation/conf/'
                                    'category_validator_map.json', V123)))

    def __added_ttv_paste_properties(self, config):
        """Add in the TTV Paste Configuration Properties"""
        config.setdefault('filter:authtoken', dict())
        config.setdefault('filter:audit', dict())
        # Add in the properties for the DEFAULT Section
        config['filter:audit']['service_name'] = ('%(mgmt_ip)s:8428', V123)
        config['filter:audit']['paste.filter_factory'] = (
            'keystonemiddleware.audit:filter_factory', V130)
        config['filter:authtoken']['paste.filter_factory'] = (
            'keystonemiddleware.auth_token:filter_factory', V123)

    def __deleted_ttv_paste_properties(self, config):
        """Remove the TTV Paste Configuration Properties"""
        config.setdefault('filter:authtoken', dict())
        # Remove the properties for the DEFAULT Section
        config['filter:authtoken'].update(dict(
            auth_port=V122, auth_host=V122,
            admin_user=V122, admin_password=V122,
            admin_tenant_name=V122, signing_dir=V122,
            auth_protocol=V122, auth_admin_prefix=V122))

==> IT15602-1.3.0.2.tar.gz: usr/lib/python2.7/site-packages/powervc_ttv/config/data_mgr.py <==
# =================================================================
# Licensed Materials - Property of IBM
#
# (c) Copyright IBM Corp. 2015 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# =================================================================

from powervc_oslo.config import data_mgr as mgr
from powervc_oslo.config import data_utils as utils
from powervc_oslo.config.data_utils import V122, V123, V130, V1302

TTV_CONF = '/etc/ttv-validation/ttv-validation.conf'
TTV_PASTE = '/etc/ttv-validation/api-paste.ini'


######################################################
#           TTV Data Manager Definition              #
######################################################
class TTVDataManager(mgr.BaseDataManager):

    def get_component_name(self):
        """Provides the name of the Component providing the Data Manager"""
        return 'validator'

    def is_supported_environment(self):
        """Specifies whether the Component is supported in this Environment"""
        return utils.is_management_system()

    def get_dependent_managers(self):
        """Specifies the Component Name of the Managers it is dependent on"""
        return ['httpd']

    ###############################################
    #     Data Manager - Configure Interface      #
    ###############################################
    def configure_component(self):
        """Performs Configuration specific to the given Component"""
        super(TTVDataManager, self).configure_component()
        # Replace the Router Factory in the Paste Configuration file
        sedbefore = 'ttv_validation.api.v1.router:APIRouter.factory'
        sedafter = 'powervc_ttv.api.v1.router:PowerVCAPIRouter.factory'
        utils.sed_replace(TTV_PASTE, sedbefore, sedafter)

    ###############################################
    #   Data Manager - Subclass Implementation    #
    ###############################################
    def _added_policy_file(self, config, cat):
        policy_file = '/opt/ibm/powervc/policy/ttv-validation/policy.json'
        config.setdefault('oslo_policy', dict())
        config['oslo_policy']['policy_file'] = (policy_file, V1302)

    def _deleted_policy_properties(self, config):
        """Helper method to delete policy file path"""
        config['DEFAULT'].update(dict(policy_file=V1302))

    def _get_service_user(self):
        """Provides the name of the Service User for the Component"""
        return 'ttv-validation'

    def _get_enabled_services(self):
        """Provides a list of the Services for the Component"""
        return ['ttv-validation-api']

    def _get_service_log_files(self):
        """Provides a list of Service Log Files for the Component"""
        logs = ['api', 'httpd-error', 'ttv_manager', 'valFlowMgr',
                'powervc-validate']
        return ['/var/log/ttv-validation/%s.log' % log for log in logs]

    def _get_added_conf_properties(self):
        """Provides a dictionary of configuration properties to add"""
        config = {TTV_CONF: dict(), TTV_PASTE: dict()}
        # Add any of the KeystoneAuth and Messaging added properties
        self._added_auth_conf_properties(config[TTV_CONF])
        # Add in the TTV specific properties to the Configuration Files
        self.__added_ttv_conf_properties(config[TTV_CONF])
        # Add messaging support for auditing
        self._added_messaging_conf_properties(config[TTV_CONF])
        self._added_ras_conf_properties(config[TTV_CONF])
        self.__added_ttv_paste_properties(config[TTV_PASTE])
        # Until Legacy is removed, we need to set update the user name
        config[TTV_CONF]['keystone_authtoken']['password'] =\
            ('aes:%(ttv-validation_password)s', V123)
        return config

    def _get_deleted_conf_properties(self):
        """Provides a dictionary of configuration properties to remove"""
        config = {TTV_CONF: dict(), TTV_PASTE: dict()}
        # Remove any of the KeystoneAuth and Messaging deleted properties
        self._deleted_auth_conf_properties(config[TTV_CONF])
        self._deleted_messaging_conf_properties(config[TTV_CONF])
        self.__deleted_ttv_paste_properties(config[TTV_PASTE])
        config[TTV_PASTE]['filter:authtoken']['auth_version'] = V123
        config[TTV_CONF]['DEFAULT'].update(
            sql_connection=V123, rpc_backend=V123)
        return config

    def _get_audit_conf_properties(self, version=None):
        """Provides a tuple of configuration properties for auditing"""
        return (TTV_PASTE, ['composite:ttv_validation_api_v1'], ['keystone'])

    def _get_included_backup_files(self):
        """Provides a list of Component files to include in a backup"""
        return ['/etc/ttv-validation']

    def _get_service_password_properties(self):
        """Provides a list of the configuration properties for passwords"""
        return [('ttv-validation', TTV_CONF,
                 'keystone_authtoken', 'password')]

    ###############################################
    #    Internal Data Manager Helper Methods     #
    ###############################################
    def __added_ttv_conf_properties(self, config):
        """Add in the TTV validator.conf Configuration Properties"""
        # Add in the properties for the DEFAULT Section
        config['DEFAULT'].update(dict(
            OCFS_TTV=('False', V123),
            host_interface=('%(ip_interface)s', V123),
            ttv_validation_api_listen_port=('8428', V123),
            ttv_validation_api_listen=('%(local_ip)s', V123),
            api_paste_config=('/etc/ttv-validation/api-paste.ini', V123),
            formatter=('powervc_ttv.api.extension.powervcFormatter', V123),
            solution_spec=('/opt/ibm/powervc/ttv-validation/'
                           'conf/solution_spec.json', V123),
            resources_def=('/opt/ibm/powervc/ttv-validation/'
                           'conf/resources.json', V123),
            category_map=('/opt/ibm/powervc/ttv-validation/conf/'
                          'category_validator_map.json', V123),
            category_validator_map=('/opt/ibm/powervc/ttv-validation/conf/'
                                    'category_validator_map.json', V123)))

    def __added_ttv_paste_properties(self, config):
        """Add in the TTV Paste Configuration Properties"""
        config.setdefault('filter:authtoken', dict())
        config.setdefault('filter:audit', dict())
        # Add in the properties for the DEFAULT Section
        config['filter:audit']['service_name'] = ('%(mgmt_ip)s:8428', V123)
        config['filter:audit']['paste.filter_factory'] = (
            'keystonemiddleware.audit:filter_factory', V130)
        config['filter:authtoken']['paste.filter_factory'] = (
            'keystonemiddleware.auth_token:filter_factory', V123)

    def __deleted_ttv_paste_properties(self, config):
        """Remove the TTV Paste Configuration Properties"""
        config.setdefault('filter:authtoken', dict())
        # Remove the properties for the DEFAULT Section
        config['filter:authtoken'].update(dict(
            auth_port=V122, auth_host=V122,
            admin_user=V122, admin_password=V122,
            admin_tenant_name=V122, signing_dir=V122,
            auth_protocol=V122, auth_admin_prefix=V122))
